@@ -17,3 +17,8 @@ sub wibble {
     $foo = 42;
     return 66;
 }
+
+require 5.004;
+use 5.004;
+require 5;
+use 5;
